@@ -4,4 +4,4 @@ DEFAULT_SESSION_TIMEOUT = timedelta(seconds=600)
 DEFAULT_GC_INTERVAL = 5.0
 DEFAULT_HEARTBEAT_INTERVAL = 25.0
 
-SOCKJS_CDN = "https://cdn.jsdelivr.net/npm/sockjs-client@1/dist/sockjs.js"  # noqa
+SOCKJS_CDN = "https://cdn.jsdelivr.net/npm/sockjs-client@1/dist/sockjs.min.js"  # noqa
