@@ -89,13 +89,11 @@ class Session(object):
         else:
             self.expires = datetime.now() + timeout
 
-    async def acquire(self, scope, manager, heartbeat=True):
+    async def acquire(self, manager, heartbeat=True):
         self.acquired = True
-        self.scope = scope
         self.manager = manager
         self._heartbeat_consumer = heartbeat
 
-        self._tick()
         self._hits += 1
 
         if self.state == STATE_NEW:
@@ -147,7 +145,6 @@ class Session(object):
         self._heartbeat_timer = loop.call_later(self.heartbeat_interval, self._heartbeat)
 
     def _feed(self, frame, data):
-        # pack messages
         if frame == FRAME_MESSAGE:
             if self._queue and self._queue[-1][0] == FRAME_MESSAGE:
                 self._queue[-1][1].append(data)
@@ -171,6 +168,8 @@ class Session(object):
 
             if frame == FRAME_HEARTBEAT:
                 self._heartbeat_consumed = True
+            else:
+                self._tick()
 
             if pack:
                 if frame == FRAME_CLOSE:
@@ -343,13 +342,15 @@ class SessionManager(dict):
                 session = self._sessions[idx]
 
                 if session.expires < now or session.expired:
+                    session._feed(FRAME_CLOSE, (3000, "Session timeout!"))
+
                     # Session is to be GC"d immediately
-                    if session.id in self._acquired_map:
-                        await self.release(session)
                     if session.state == STATE_OPEN:
                         await session.remote_close()
                     if session.state == STATE_CLOSING:
                         await session.remote_closed()
+                    if session.id in self._acquired_map:
+                        await self.release(session)
 
                     del self[session.id]
                     del self._sessions[idx]
@@ -383,10 +384,12 @@ class SessionManager(dict):
                 if default is not empty:
                     return default
                 raise KeyError(sid)
+        else:
+            session.scope = scope
 
         return session
 
-    async def acquire(self, scope, session):
+    async def acquire(self, session):
         sid = session.id
 
         if sid in self._acquired_map:
@@ -394,7 +397,7 @@ class SessionManager(dict):
         if sid not in self:
             raise KeyError("Unknown session")
 
-        await session.acquire(scope, self)
+        await session.acquire(self)
 
         self._acquired_map[sid] = True
         return session
