@@ -163,7 +163,7 @@ class HttpStreamingConsumer(AsyncHttpConsumer):
 
         # acquire session
         try:
-            await self.manager.acquire(self.scope, self.session)
+            await self.manager.acquire(self.session)
         except SessionIsAcquired:
             await self.send_message(close_frame(2010, "Another connection still open"))
             return
@@ -181,7 +181,7 @@ class HttpStreamingConsumer(AsyncHttpConsumer):
                 if frame == FRAME_CLOSE:
                     await self.session.remote_closed()
                     await self.send_message(payload)
-                    return
+                    break
                 else:
                     stop = await self.send_message(payload, more_body=True)
                     if stop:
