@@ -35,7 +35,7 @@ class WebsocketConsumer(BaseWebsocketConsumer):
             return
 
         try:
-            await self.manager.acquire(self.scope, self.session)
+            await self.manager.acquire(self.session)
         except SessionIsAcquired:
             await self.send(close_frame(2010, "Another connection still open"))
             return
@@ -56,10 +56,7 @@ class WebsocketConsumer(BaseWebsocketConsumer):
                 except SessionIsClosed:
                     break
 
-                try:
-                    await self.send(payload)
-                except OSError:
-                    pass  # ignore "cannot write to closed consumer"
+                await self.send(payload)
 
                 if frame == FRAME_CLOSE:
                     try:
